@@ -11,9 +11,10 @@
 #include <QTimer>
 
 #include <KCupsPrinter.h>
+#include <kcupslib_export.h>
 
 class KCupsRequest;
-class Q_DECL_EXPORT PrinterModel : public QStandardItemModel
+class KCUPSLIB_EXPORT PrinterModel : public QStandardItemModel
 {
     Q_OBJECT
     Q_ENUMS(JobAction)
