@@ -17,7 +17,9 @@
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     PrintQueue app(argc, argv);
     app.setOrganizationDomain(QLatin1String("org.kde"));
 
